#!/bin/sh -x
#
# Function:
#  - changes the current link to the specified version
#  
#  The system is expected to be rebooted after running this script

# the link to the application
linkname=Leica3DD

# the name of the product
prodname=leica3dd

# the versioninfo file
versioninfo=versioninfo.xml

# error codes
E_OPT=65
E_DEF=60
E_ROOT_DIR=3
E_TEMP_DIR=4
E_DIR=5
E_NOT_FOUND=6
E_PLATFORM=50

# utility functions
usage()
{
	echo "usage: `basename $0` -r <rollback-version> -u"
    echo ""
    echo "  -r <rollback-version> : the version to rollback, e.g. 0.3.5.0"
	echo "  -u update the versioninfo.xml file (when manually running this script)"
    echo "  note that this version must exist on disk"
	exit $E_OPT
}

osname=`uname -s`

# where to extract
if [ "$osname" == 'CYGWIN_NT-6.1' ]; then
	rootdir=/cygdrive/c/temp
elif [ "$osname" == Linux ]; then
	rootdir=/mnt_data
else
	echo "error: OS $osname not supported!"
	exit $E_PLATFORM
fi

# mandatory flags
vvflag=
rollbackversion=
uflag=0

# parse command line
while getopts "r:u" name
do
    case $name in
        r) rvflag=1
            rollbackversion="$OPTARG";;
        u) uflag=1 ;;
        ?) usage;;
    esac
done

# argument sanity checks
if [ -z "$rollbackversion" ]; then
	usage
fi

if [ ! -e $rootdir/$versioninfo ]; then
	echo "error: $rootdir/$versioninfo does not exist!"
    exit $E_NOT_FOUND
fi

# change to the rollback directory to continue
cd $rootdir

rollbackdir=`find . -name $prodname-$rollbackversion-mono`

if [ ! -z "$rollbackdir" ]; then

	# remove the link to the broken SW
	if [ -h $linkname ]; then 
		rm -f $linkname
	fi

	# create link to the found rollback version
	ln -sf $rollbackdir $linkname

	# Change version information in versioninfo.xml
	# This is done from the application.
	# However, they are left here to test this script manually
	if [ ! -z "$rollbackversion" ] && [ $uflag -gt 0 ]; then
		sedscript=cmds.sed
		echo "s/\(.*<Current>\).*\(<\/Current>.*\)/\1\2/1" > $sedscript
		echo "s/\(.*<Desired>\).*\(<\/Desired>.*\)/\1$rollbackversion\2/1" >> $sedscript
		echo "s/\(.*<Rollback>\).*\(<\/Rollback>.*\)/\1\2/1" >> $sedscript

		sed -f $sedscript < $versioninfo > $versioninfo.tmp
		mv $versioninfo.tmp $versioninfo
		rm $sedscript
	fi
else
	exit $E_NOT_FOUND
fi

cd -

exit 0
