#!/bin/sh

PROJ=Leica3DD
ARCH=leica3dd

logfile=/var/log/starter3dd.log
root_dir=/mnt_data/$PROJ/bin/
executable=$PROJ.Program.Starter.exe
remove_old_platforms=/usr/bin/remove_old_platforms.sh

#set the flag for a filesystem check during next reboot.
#this flag will be removed, when the application is correctly shut down
touch /mnt_data/forcefsck

#remove old rootfs images, which are not used anymore
if [ -e $remove_old_platforms ]; then
	"$remove_old_platforms"
fi

#default
build=Release

if [ -d $root_dir$build ]; then
	xli -onroot -center $root_dir$build/images/splash1.gif
fi

# rename possibly existing logfiles - keeping the last 5 logfiles
for x_0 in 3 2 1 0
do
	if [ -f $logfile.$x_0 ]; then
		x_1=`expr $x_0 + 1`
		mv -f $logfile.$x_0 $logfile.$x_1
	fi
done

if [ -f $logfile ]; then
	mv -f $logfile $logfile.0
fi

echo "===============================" > $logfile
date -Iseconds >> $logfile

echo "=== tune disk cache presets..." >> $logfile
sync
# minimize kernel likelyness to move code/data into swap
# (might not have any effect if swap is not enabled)
echo 1 >/proc/sys/vm/swappiness
# tell kernel to more likely reuse inode caches
echo 100000 >/proc/sys/vm/vfs_cache_pressure
sync
# free pagecache (slab pool?)
echo 1 >/proc/sys/vm/drop_caches
# free dentries and inodes (slab pools, e.g. nfs_inode_cache)
echo 2 >/proc/sys/vm/drop_caches
# free pagecache, dentries and inodes
echo 3 >/proc/sys/vm/drop_caches

echo "=== reporting memory state..." >> $logfile
cat /proc/meminfo | grep "^MemFree:" >> $logfile

echo "=== starting application..." >> $logfile


if [ ! -d $root_dir$build ]; then
	# fallback to debug build
	echo "Release build does not exist, falling back to Debug"
	build=Debug

	if [ ! -d $root_dir$build ]; then
		echo "neither Debug nor Release build exist, exiting..."
		exit 1
	fi
fi

cd $root_dir$build || exit 1

if [ "X$DISPLAY" == "X" ]; then
	export DISPLAY=:0
fi

echo DISPLAY=$DISPLAY >> $logfile
echo build=$build >> $logfile

mono $executable >> $logfile 2>&1

# Set the menu for debugging
/root/set_full_menu.sh

# Wait until the program has really started and set
# the splash screen back

if [ -d $root_dir$build ]; then
	for i in {1..5}
	do
		xli -onroot -center $root_dir$build/images/splash1.gif
		sleep 2
	done
fi

sleep 10
xli -onroot -center /etc/icewm/splash.gif

# ### EOF ###

